aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorThanos Makatos <thanos.makatos@nutanix.com>2019-11-05 11:21:07 -0500
committerThanos Makatos <thanos.makatos@nutanix.com>2019-11-05 11:21:07 -0500
commitb24e948208e03e5e00e4654d64c4190c1889a90a (patch)
treedc769f3d7ac27b0160ae020b0ce1515f95c66c69
parent2940ed17585f6b943183bd1209c563bf4ce7ff5f (diff)
downloadlibvfio-user-b24e948208e03e5e00e4654d64c4190c1889a90a.zip
libvfio-user-b24e948208e03e5e00e4654d64c4190c1889a90a.tar.gz
libvfio-user-b24e948208e03e5e00e4654d64c4190c1889a90a.tar.bz2
rename obsolete 'PCI server' with libmuser
Signed-off-by: Thanos Makatos <thanos.makatos@nutanix.com>
-rw-r--r--kmod/muser.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmod/muser.c b/kmod/muser.c
index d07d473..9cb9256 100644
--- a/kmod/muser.c
+++ b/kmod/muser.c
@@ -798,7 +798,7 @@ static int muser_iommu_dma_unmap(struct muser_dev *const mudev,
len = dma_map->length;
err = muser_process_dma_unmap(mudev, dma_map);
if (unlikely(err))
- muser_dbg("failed to request PCI server to munmap: %d", err);
+ muser_dbg("failed to request libmuser to munmap: %d", err);
err = put_dma_map(mudev, dma_map, NR_PAGES(len));
if (unlikely(err)) {
@@ -814,7 +814,7 @@ out:
/*
* FIXME There can be multiple DMA map calls per device. If each of these calls
* are serialised (this can be enforced by muser), then we tell PCI server to
* mmap the control device. Do we need to distinguish between the different
* DMA map calls at this stage if we can enforce only one outstanding DMA map
* call? What happens when the DMA map happens too early, before GET_DEVICE_FD
@@ -880,7 +880,7 @@ int muser_open(struct mdev_device *mdev)
int err2;
/*
* TODO we might have triggered some notifiers which will have
* caused PCI server to mmap. If open fails then PCI server dies
* therefore things get automatically cleaned up (e.g.
* vfio_unpin etc.)?
*/
@@ -814,7 +814,7 @@ out:
/*
* FIXME There can be multiple DMA map calls per device. If each of these calls
- * are serialised (this can be enforced by muser), then we tell PCI server to
+ * are serialised (this can be enforced by muser), then we tell libmuser to
* mmap the control device. Do we need to distinguish between the different
* DMA map calls at this stage if we can enforce only one outstanding DMA map
@@ -880,7 +880,7 @@ int muser_open(struct mdev_device *mdev)
/*
* TODO we might have triggered some notifiers which will have
- * caused PCI server to mmap. If open fails then PCI server dies
+ * caused libmuser to mmap. If open fails then libmuser dies
* therefore things get automatically cleaned up (e.g.
* vfio_unpin etc.)?